@@ -1,6 +1,10 @@
 import sys
 import types
-from _pytest.python import PyCollector
+import pytest
+
+
+PYTEST_GTE_7_0 = getattr(pytest, 'version_tuple', (0, 0)) >= (7, 0)
+PYTEST_GTE_5_4 = PYTEST_GTE_7_0 or hasattr(pytest.Collector, 'from_parent')
 
 
 def trace_function(funcobj, *args, **kwargs):
@@ -55,33 +59,35 @@ def evaluate_shared_behavior(funcobj):
     return funcobj._shared_functions
 
 
-class DescribeBlock(PyCollector):
+class DescribeBlock(pytest.Module):
     """Module-like object representing the scope of a describe block"""
 
     @classmethod
     def from_parent(cls, parent, obj):
-        name = obj.__name__
-        try:
-            from_parent_super = super().from_parent
-        except AttributeError:  # PyTest < 5.4
-            self = cls(name, parent)
+        """Construct a new node for the describe block"""
+        name = getattr(obj, '_mangled_name', obj.__name__)
+        nodeid = parent.nodeid + '::' + name
+        if PYTEST_GTE_7_0:
+            self = super().from_parent(
+                parent=parent, path=parent.path, nodeid=nodeid)
+        elif PYTEST_GTE_5_4:
+            self = super().from_parent(
+                parent=parent, fspath=parent.fspath, nodeid=nodeid)
         else:
-            self = from_parent_super(parent, name=name)
-        self._name = getattr(obj, '_mangled_name', name)
+            self = cls(parent=parent, fspath=parent.fspath, nodeid=nodeid)
+        self.name = name
         self.funcobj = obj
         return self
 
     def collect(self):
+        """Get list of children"""
         self.session._fixturemanager.parsefactories(self)
         return super().collect()
 
     def _getobj(self):
+        """Get the underlying Python object"""
         return self._importtestmodule()
 
-    def _makeid(self):
-        """Magic that makes fixtures local to each scope"""
-        return f'{self.parent.nodeid}::{self._name}'
-
     def _importtestmodule(self):
         """Import a describe block as if it was a module"""
         module = make_module_from_function(self.funcobj)
@@ -100,7 +106,7 @@ class DescribeBlock(PyCollector):
         return False
 
     def __repr__(self):
-        return f"<{self.__class__.__name__} {self._name!r}>"
+        return f"<{self.__class__.__name__} {self.name!r}>"
 
 
 def pytest_pycollect_makeitem(collector, name, obj):
