@@ -1,4 +1,5 @@
 import py
+import re
 
 pytest_plugins = 'pytester'
 
@@ -20,11 +21,12 @@ def test_collect_custom_prefix(testdir):
     """))
 
     result = testdir.runpytest('--collectonly')
-    print(result.outlines)
-    assert result.stdout.lines[3:-2] == [
-        "collected 1 items",
-        "<Module 'a_dir/test_a.py'>",
-        "  <DescribeBlock 'foo_scope'>",
-        "    <DescribeBlock 'bar_context'>",
-        "      <Function 'passes'>",
-    ]
+    expected_lines = map(re.compile, [
+        r"collected 1 item(s)?",
+        r"\s*<Module '?(a_dir/)?test_a.py'?>",
+        r"\s*<DescribeBlock '?foo_scope'?>",
+        r"\s*<DescribeBlock '?bar_context'?>",
+        r"\s*<Function '?passes'?>",
+    ])
+    for line in expected_lines:
+        assert any([line.match(r) is not None for r in result.outlines])
