@@ -1,7 +1,7 @@
 def assert_outcomes(result, **expected):
     outcomes = result.parseoutcomes()
 
-    for key in 'seconds', 'pytest-warnings', 'warnings', 'warning':
+    for key in 'seconds', 'warning', 'warnings':
         if key in outcomes:
             del outcomes[key]
 
